aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-http2.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-http2.c')
-rw-r--r--epan/dissectors/packet-http2.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-http2.c b/epan/dissectors/packet-http2.c
index 34978b1728..2fbd1f086a 100644
--- a/epan/dissectors/packet-http2.c
+++ b/epan/dissectors/packet-http2.c
@@ -26,8 +26,8 @@
/*
* The information used comes from:
* Hypertext Transfer Protocol version 2 draft-ietf-httpbis-http2-15
* HTTP Header Compression draft-ietf-httpbis-header-compression-09
* HTTP Alternative Services draft-ietf-httpbis-alt-svc-04
*
* TODO
@@ -1389,7 +1389,7 @@ dissect_http2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
col_clear(pinfo->cinfo, COL_INFO);
ti = proto_tree_add_item(tree, proto_http2, tvb, 0, -1, ENC_NA);
- proto_item_append_text(ti, " (draft-15)");
+ proto_item_append_text(ti, " (draft-16)");
http2_tree = proto_item_add_subtree(ti, ett_http2);
@@ -26,8 +26,8 @@
/*
* The information used comes from:
- * Hypertext Transfer Protocol version 2 draft-ietf-httpbis-http2-15
- * HTTP Header Compression draft-ietf-httpbis-header-compression-09
+ * Hypertext Transfer Protocol version 2 draft-ietf-httpbis-http2-16
+ * HTTP Header Compression draft-ietf-httpbis-header-compression-10
* HTTP Alternative Services draft-ietf-httpbis-alt-svc-04
*